# gracedb-sdk

A modern, performant REST API client for GraceDB, based on [Requests](http://python-requests.org/). For documentation, see https://gracedb-sdk.readthedocs.io.

## Benchmarks

Time in seconds to perform common tasks [lscsoft/ligo-gracedb](https://git.ligo.org/lscsoft/gracedb-client). Measured on a residential Internet connection on the US East Coast.

![benchmarks compared to ligo-gracedb](https://git.ligo.org/emfollow/gracedb-sdk/snippets/92/raw)